@@ -29,6 +29,7 @@ use English qw( -no_match_vars );
 use IO::File;
 
 my $apps = [
+
 #   { app => 'mysql-server-5', info => { port => 'mysql50-server', dport=>'mysql5',  yum =>'mysql-server'} },
 #   { app => 'apache22'      , info => { port => 'apache22',       dport=>'',     yum => 'httpd' } },
 ];
@@ -36,24 +37,25 @@ my $apps = [
 $EUID == 0 or croak "You will have better luck if you run me as root.\n";
 
 my @failed;
-foreach ( @$apps ) {
+foreach (@$apps) {
     my $name = $_->{app} or croak 'missing app name';
     install_app( $name, $_->{info} );
-};
+}
 
 foreach ( get_perl_modules() ) {
-#print Dumper($_);
-    my $module = $_->{module} or croak 'missing module name';
-    my $info   = $_->{info};
+
+    #print Dumper($_);
+    my $module  = $_->{module} or croak 'missing module name';
+    my $info    = $_->{info};
     my $version = $info->{version} || '';
     print "checking for $module $version\n";
 
-    eval "use $module $version"; ## no critic (Eval)
-    next if ! $EVAL_ERROR;
+    eval "use $module $version";    ## no critic (Eval)
+    next if !$EVAL_ERROR;
     next if $info->{ships_with} && $info->{ships_with} eq 'perl';
 
     install_module( $module, $info, $version );
-    eval "use $module $version"; ## no critic (Eval)
+    eval "use $module $version";    ## no critic (Eval)
     if ($EVAL_ERROR) {
         push @failed, $module;
     }
@@ -70,76 +72,78 @@ exit;
 sub get_perl_modules {
     if ( -f 'dist.ini' ) {
         return get_perl_modules_from_ini();
-    };
+    }
     if ( -f 'Makefile.PL' ) {
         return get_perl_modules_from_Makefile_PL();
-    };
+    }
     croak "unable to find module list. Run this script in the dist dir\n";
-};
+}
 
 sub get_perl_modules_from_Makefile_PL {
-    my $fh = new IO::File 'Makefile.PL', 'r'  ## no critic (Indirect)
+    my $fh = new IO::File 'Makefile.PL', 'r'    ## no critic (Indirect)
         or croak "unable to read Makefile.PL\n";
 
     my $in = 0;
     my @modules;
-    while (my $line = <$fh> ) {
+    while ( my $line = <$fh> ) {
         if ( $line =~ /PREREQ_PM/ ) {
             $in++;
             next;
-        };
-        next if ! $in;
+        }
+        next if !$in;
         last if $line =~ /}/;
-        next if $line !~ /=/;  # no = char means not a module
-        my ($mod,$ver) = split /\s*=\s*/, $line;
-        $mod =~ s/[\s'"\#]*//gx;   # remove whitespace and quotes
-        next if ! $mod;
+        next if $line !~ /=/;                   # no = char means not a module
+        my ( $mod, $ver ) = split /\s*=\s*/, $line;
+        $mod =~ s/[\s'"\#]*//gx;                # remove whitespace and quotes
+        next if !$mod;
         push @modules, name_overrides($mod);
-#print "module: .$mod.\n";
+
+        #print "module: .$mod.\n";
     }
     $fh->close;
     return @modules;
-};
+}
 
 sub get_perl_modules_from_ini {
-    my $fh = new IO::File ( 'dist.ini', 'r' )  ## no critic (Indirect)
+    my $fh = new IO::File( 'dist.ini', 'r' )    ## no critic (Indirect)
         or croak "unable to read dist.ini\n";
 
     my $in = 0;
     my @modules;
-    while (my $line = <$fh> ) {
-        if ( '[Prereqs]' eq substr($line,0,9) ) {
+    while ( my $line = <$fh> ) {
+        if ( '[Prereqs]' eq substr( $line, 0, 9 ) ) {
             $in++;
             next;
-        };
-        next if ! $in;
-        last if '[' eq substr($line,0,1); # [...] starts a new section
-        my ($mod,$ver) = split /\s*=\s*/, $line;
-        $mod =~ s/\s*//g;                 # remove whitespace
+        }
+        next if !$in;
+        last if '[' eq substr( $line, 0, 1 );    # [...] starts a new section
+        my ( $mod, $ver ) = split /\s*=\s*/, $line;
+        $mod =~ s/\s*//g;                        # remove whitespace
         $mod =~ s/^;//g;
-        next if ! $mod || ! defined $ver;
+        next if !$mod || !defined $ver;
         push @modules, name_overrides($mod);
     }
     $fh->close;
-#print Dumper(\@modules);
+
+    #print Dumper(\@modules);
     return @modules;
-};
+}
 
 sub install_app {
-    my ( $app, $info) = @_;
+    my ( $app, $info ) = @_;
 
-    return install_app_darwin($app, $info ) if lc($OSNAME) eq 'darwin';
-    return install_app_freebsd($app, $info ) if lc($OSNAME) eq 'freebsd';
+    return install_app_darwin( $app, $info ) if lc($OSNAME) eq 'darwin';
+    return install_app_freebsd( $app, $info ) if lc($OSNAME) eq 'freebsd';
     return install_app_linux( $app, $info ) if lc($OSNAME) eq 'linux';
     return;
-};
+}
 
 sub install_app_darwin {
-    my ($app, $info ) = @_;
+    my ( $app, $info ) = @_;
 
     my $port = $info->{dport} || $info->{port} || $app;
 
-    if ( ! -x '/opt/local/bin/port' ) {
+    if ( !-x '/opt/local/bin/port' ) {
         print "MacPorts is not installed! Consider installing it.\n";
         return;
     }
@@ -150,7 +154,7 @@ sub install_app_darwin {
 }
 
 sub install_app_freebsd {
-    my ($app, $info ) = @_;
+    my ( $app, $info ) = @_;
 
     print " from ports...";
     my $name = $info->{port} || $app;
@@ -166,12 +170,12 @@ sub install_app_freebsd {
         print " from ports ($portdir)\n";
         system "make install clean"
             and carp "'make install clean' failed for port $app\n";
-    };
+    }
     return;
-};
+}
 
 sub install_app_linux {
-    my ($app, $info ) = @_;
+    my ( $app, $info ) = @_;
 
     if ( -x '/usr/bin/yum' ) {
         my $rpm = $info->{yum} || $app;
@@ -183,29 +187,28 @@ sub install_app_linux {
     }
     carp "no Linux package manager detected\n";
     return;
-};
-
+}
 
 sub install_module {
-    my ($module, $info, $version) = @_;
+    my ( $module, $info, $version ) = @_;
 
-    install_module_darwin($module, $info, $version)
+    install_module_darwin( $module, $info, $version )
         if lc($OSNAME) eq 'darwin';
 
-    install_module_freebsd($module, $info, $version)
+    install_module_freebsd( $module, $info, $version )
         if lc($OSNAME) eq 'freebsd';
 
-    install_module_linux( $module, $info, $version)
+    install_module_linux( $module, $info, $version )
         if lc($OSNAME) eq 'linux';
 
-    eval "require $module"; ## no critic (Eval)
-    return 1 if ! $EVAL_ERROR;
+    eval "require $module";    ## no critic (Eval)
+    return 1 if !$EVAL_ERROR;
 
-    return install_module_cpan($module, $version);
-};
+    return install_module_cpan( $module, $version );
+}
 
 sub install_module_cpan {
-    my ($module, $version) = @_;
+    my ( $module, $version ) = @_;
 
     print " from CPAN...";
     sleep 1;
@@ -213,11 +216,11 @@ sub install_module_cpan {
     # this causes problems when CPAN is not configured.
     #$ENV{PERL_MM_USE_DEFAULT} = 1;       # supress CPAN prompts
 
-    local $ENV{FTP_PASSIVE} = 1;          # for FTP behind NAT/firewalls
+    local $ENV{FTP_PASSIVE} = 1;    # for FTP behind NAT/firewalls
 
-    # some Linux distros break CPAN by auto/preconfiguring it with no URL mirrors.
-    # this works around that annoying little habit
-    $CPAN::Config = get_cpan_config();   ## no critic (Package)
+# some Linux distros break CPAN by auto/preconfiguring it with no URL mirrors.
+# this works around that annoying little habit
+    $CPAN::Config = get_cpan_config();    ## no critic (Package)
 
     # a hack to grab the latest version on CPAN before its hits the mirrors
     if ( $module eq 'Provision::Unix' && $version ) {
@@ -228,10 +231,10 @@ sub install_module_cpan {
 }
 
 sub install_module_darwin {
-    my ($module, $info, $version) = @_;
+    my ( $module, $info, $version ) = @_;
 
     my $dport = '/opt/local/bin/port';
-    if ( ! -x $dport ) {
+    if ( !-x $dport ) {
         print "MacPorts is not installed! Consider installing it.\n";
         return;
     }
@@ -244,7 +247,7 @@ sub install_module_darwin {
 }
 
 sub install_module_freebsd {
-    my ($module, $info, $version) = @_;
+    my ( $module, $info, $version ) = @_;
 
     my $name = $info->{port} || $module;
     my $portname = "p5-$name";
@@ -258,14 +261,14 @@ sub install_module_freebsd {
     my $category = $info->{category} || '*';
     my ($portdir) = glob "/usr/ports/$category/$portname";
 
-    if ( ! $portdir || ! -d $portdir ) {
+    if ( !$portdir || !-d $portdir ) {
         print "oops, no match at /usr/ports/$category/$portname\n";
         return;
-    };
+    }
 
-    if ( ! chdir $portdir ) {
+    if ( !chdir $portdir ) {
         print "unable to cd to /usr/ports/$category/$portname\n";
-    };
+    }
 
     print " from ports ($portdir)\n";
     system "make install clean"
@@ -274,21 +277,21 @@ sub install_module_freebsd {
 }
 
 sub install_module_linux {
-    my ($module, $info, $version) = @_;
+    my ( $module, $info, $version ) = @_;
 
     my $package;
     if ( -x '/usr/bin/yum' ) {
-        return install_module_linux_yum($module, $info);
+        return install_module_linux_yum( $module, $info );
     }
     elsif ( -x '/usr/bin/apt-get' ) {
-        return install_module_linux_apt($module, $info);
+        return install_module_linux_apt( $module, $info );
     }
     carp "no Linux package manager detected\n";
     return;
-};
+}
 
 sub install_module_linux_yum {
-    my ($module, $info) = @_;
+    my ( $module, $info ) = @_;
     my $package;
     if ( $info->{yum} ) {
         $package = $info->{yum};
@@ -296,12 +299,12 @@ sub install_module_linux_yum {
     else {
         $package = "perl-$module";
         $package =~ s/::/-/g;
-    };
+    }
     return system "/usr/bin/yum -y install $package";
-};
+}
 
 sub install_module_linux_apt {
-    my ($module, $info) = @_;
+    my ( $module, $info ) = @_;
     my $package;
     if ( $info->{apt} ) {
         $package = $info->{apt};
@@ -309,83 +312,100 @@ sub install_module_linux_apt {
     else {
         $package = 'lib' . $module . '-perl';
         $package =~ s/::/-/g;
-    };
+    }
     return system "/usr/bin/apt-get -y install $package";
-};
+}
 
 sub is_freebsd_port_installed {
-    my ($portname, $display_name) = @_;
+    my ( $portname, $display_name ) = @_;
     $display_name ||= $portname;
 
-    if ( grep {/$portname/x} `/usr/sbin/pkg_info` ) { ## no critic (Backtick)
+    if ( grep {/$portname/x} `/usr/sbin/pkg_info` ) {  ## no critic (Backtick)
         return print "$display_name is installed.\n";
     }
-    if ( `/usr/sbin/pkg info -x $portname` ) {        ## no critic (Backtick)
+    if (`/usr/sbin/pkg info -x $portname`) {           ## no critic (Backtick)
         return print "$display_name is installed.\n";
     }
     return 0;
-};
+}
 
 sub get_cpan_config {
 
-    my $ftp = `which ftp`; chomp $ftp;  ## no critic (BackTick)
-    my $gzip = `which gzip`; chomp $gzip;  ## no critic (BackTick)
-    my $unzip = `which unzip`; chomp $unzip;  ## no critic (BackTick)
-    my $tar  = `which tar`; chomp $tar;  ## no critic (BackTick)
-    my $make = `which make`; chomp $make;  ## no critic (BackTick)
-    my $wget = `which wget`; chomp $wget;  ## no critic (BackTick)
+## no critic (BackTick)
+    my $ftp   = `which ftp`;
+    my $gzip  = `which gzip`;
+    my $unzip = `which unzip`;
+    my $tar   = `which tar`;
+    my $make  = `which make`;
+    my $wget  = `which wget`;
+    chomp( $ftp, $wget, $gzip, $unzip, $tar, $make );
 
-    return
-{
-  'build_cache' => q[10],
-  'build_dir' => qq[$ENV{HOME}/.cpan/build],
-  'cache_metadata' => q[1],
-  'cpan_home' => qq[$ENV{HOME}/.cpan],
-  'ftp' => $ftp,
-  'ftp_proxy' => q[],
-  'getcwd' => q[cwd],
-  'gpg' => q[],
-  'gzip' => $gzip,
-  'histfile' => qq[$ENV{HOME}/.cpan/histfile],
-  'histsize' => q[100],
-  'http_proxy' => q[],
-  'inactivity_timeout' => q[5],
-  'index_expire' => q[1],
-  'inhibit_startup_message' => q[1],
-  'keep_source_where' => qq[$ENV{HOME}/.cpan/sources],
-  'lynx' => q[],
-  'make' => $make,
-  'make_arg' => q[],
-  'make_install_arg' => q[],
-  'makepl_arg' => q[],
-  'ncftp' => q[],
-  'ncftpget' => q[],
-  'no_proxy' => q[],
-  'pager' => q[less],
-  'prerequisites_policy' => q[follow],
-  'scan_cache' => q[atstart],
-  'shell' => q[/bin/csh],
-  'tar' => $tar,
-  'term_is_latin' => q[1],
-  'unzip' => $unzip,
-  'urllist' => [ 'http://www.perl.com/CPAN/', 'http://mirrors.kernel.org/pub/CPAN/', 'ftp://cpan.cs.utah.edu/pub/CPAN/', 'ftp://mirrors.kernel.org/pub/CPAN', 'ftp://osl.uoregon.edu/CPAN/', 'http://cpan.yahoo.com/', 'ftp://ftp.funet.fi/pub/languages/perl/CPAN/' ],
-  'wget' => $wget, };
+    return {
+        'build_cache'             => q[10],
+        'build_dir'               => qq[$ENV{HOME}/.cpan/build],
+        'cache_metadata'          => q[1],
+        'cpan_home'               => qq[$ENV{HOME}/.cpan],
+        'ftp'                     => $ftp,
+        'ftp_proxy'               => q[],
+        'getcwd'                  => q[cwd],
+        'gpg'                     => q[],
+        'gzip'                    => $gzip,
+        'histfile'                => qq[$ENV{HOME}/.cpan/histfile],
+        'histsize'                => q[100],
+        'http_proxy'              => q[],
+        'inactivity_timeout'      => q[5],
+        'index_expire'            => q[1],
+        'inhibit_startup_message' => q[1],
+        'keep_source_where'       => qq[$ENV{HOME}/.cpan/sources],
+        'lynx'                    => q[],
+        'make'                    => $make,
+        'make_arg'                => q[],
+        'make_install_arg'        => q[],
+        'makepl_arg'              => q[],
+        'ncftp'                   => q[],
+        'ncftpget'                => q[],
+        'no_proxy'                => q[],
+        'pager'                   => q[less],
+        'prerequisites_policy'    => q[follow],
+        'scan_cache'              => q[atstart],
+        'shell'                   => q[/bin/csh],
+        'tar'                     => $tar,
+        'term_is_latin'           => q[1],
+        'unzip'                   => $unzip,
+        'urllist'                 => [
+            'http://www.perl.com/CPAN/',
+            'http://mirrors.kernel.org/pub/CPAN/',
+            'ftp://cpan.cs.utah.edu/pub/CPAN/',
+            'ftp://mirrors.kernel.org/pub/CPAN',
+            'ftp://osl.uoregon.edu/CPAN/',
+            'http://cpan.yahoo.com/',
+            'ftp://ftp.funet.fi/pub/languages/perl/CPAN/'
+        ],
+        'wget' => $wget,
+    };
 }
 
 sub name_overrides {
     my $mod = shift;
-# Package and port managers have naming conventions for perl modules. The
-# methods will typically work out the name based on the module name and a
-# couple rules. When that doesn't work, add entries here for FreeBSD (port),
-# MacPorts ($dport), yum, and apt.
+
+  # Package and port managers have naming conventions for perl modules. The
+  # methods will typically work out the name based on the module name and a
+  # couple rules. When that doesn't work, add entries here for FreeBSD (port),
+  # MacPorts ($dport), yum, and apt.
     my @modules = (
-        { module=>'LWP::UserAgent', info => { cat=>'www', port=>'p5-libwww', dport=>'p5-libwww-perl' }, },
-        { module=>'Mail::Send'    , info => { port => 'Mail::Tools', }  },
+        {   module => 'LWP::UserAgent',
+            info   => {
+                cat   => 'www',
+                port  => 'p5-libwww',
+                dport => 'p5-libwww-perl'
+            },
+        },
+        { module => 'Mail::Send', info => { port => 'Mail::Tools', } },
     );
     my ($match) = grep { $_->{module} eq $mod } @modules;
     return $match if $match;
-    return { module=>$mod, info => { } };
-};
+    return { module => $mod, info => {} };
+}
 
 # PODNAME: install_deps.pl
 # ABSTRACT: install dependencies with package manager or CPAN
@@ -399,7 +419,7 @@ install_deps.pl - install dependencies with package manager or CPAN
 
 =head1 VERSION
 
-version 0.20130520
+version 0.20130521
 
 =head1 AUTHORS
 
