@@ -1,6 +1,6 @@
 package Mail::DMARC::Report::URI;
 {
-  $Mail::DMARC::Report::URI::VERSION = '0.20130520';
+  $Mail::DMARC::Report::URI::VERSION = '0.20130521';
 }
 use strict;
 use warnings;
@@ -11,46 +11,50 @@ use URI;
 sub new {
     my $class = shift;
     return bless {}, $class;
-};
+}
 
 sub parse {
-    my ($self, $str) = @_;
+    my ( $self, $str ) = @_;
 
     my @valids = ();
     foreach my $raw ( split /,/, $str ) {
-        my ($u, $size_f) = split /!/, $raw;
+        my ( $u, $size_f ) = split /!/, $raw;
         my $bytes = $self->get_size_limit($size_f);
         my $uri = URI->new($u) or carp "can't parse URI from $u";
-        if ( $uri->scheme eq 'mailto' && lc substr($u, 0, 7) eq 'mailto:' ) {
+        if ( $uri->scheme eq 'mailto' && lc substr( $u, 0, 7 ) eq 'mailto:' )
+        {
             push @valids, { max_bytes => $bytes, uri => $uri };
             next;
-        };
-        if ( $uri->scheme =~ /^http(s)?/x && lc substr($u, 0, 4) eq 'http') {
+        }
+        if ( $uri->scheme =~ /^http(s)?/x && lc substr( $u, 0, 4 ) eq 'http' )
+        {
             push @valids, { max_bytes => $bytes, uri => $uri };
             next;
-        };
-# 12.1 Discovery - URI schemes found in "rua" tag that are not implemented by
-#                  a Mail Receiver MUST be ignored.
-    };
+        }
+
+ # 12.1 Discovery - URI schemes found in "rua" tag that are not implemented by
+ #                  a Mail Receiver MUST be ignored.
+    }
     return \@valids;
-};
+}
 
 sub get_size_limit {
-    my ($self, $size) = @_;
-    return 0 if ! defined $size;       # no limit
-    return $size if $size =~ /^\d+$/;  # no units, raw byte count
+    my ( $self, $size ) = @_;
+    return 0 if !defined $size;          # no limit
+    return $size if $size =~ /^\d+$/;    # no units, raw byte count
 
 # 6.3 Formal Definition
 # units are considered to be powers of two; a kilobyte is 2^10, a megabyte is 2^20,
     my $unit = lc chop $size;
-    return $size * (2 ** 10) if 'k' eq $unit;
-    return $size * (2 ** 20) if 'm' eq $unit;
-    return $size * (2 ** 30) if 'g' eq $unit;
-    return $size * (2 ** 40) if 't' eq $unit;
+    return $size * ( 2**10 ) if 'k' eq $unit;
+    return $size * ( 2**20 ) if 'm' eq $unit;
+    return $size * ( 2**30 ) if 'g' eq $unit;
+    return $size * ( 2**40 ) if 't' eq $unit;
     croak "unrecognized unit ($unit) in size ($size)";
-};
+}
 
 1;
+
 # ABSTRACT: a DMARC reporting URI
 
 
@@ -62,7 +66,7 @@ Mail::DMARC::Report::URI - a DMARC reporting URI
 
 =head1 VERSION
 
-version 0.20130520
+version 0.20130521
 
 =head1 DESCRIPTION
 
